import 'dart:async';
import 'dart:convert';
import 'dart:io';
import 'package:http/http.dart' as http;
import 'package:yaml/yaml.dart' as yaml;

Future<RepubSpec> loadRepubSpec(Directory dir) async {
  var file = new File.fromUri(dir.uri.resolve('repubspec.yaml'));
  if (!await file.exists()) return null;
  yaml.YamlMap y = yaml.loadYaml(await file.readAsString());
  return new RepubSpec.parse(y);
}

class RepubAuthClient extends http.IOClient {
  final http.Client _inner = new http.Client();
  final RepubSpecAuth auth;
  RepubAuthClient(this.auth);

  @override
  send(request) {
    request.headers[HttpHeaders.AUTHORIZATION] = 'Basic ' +
        BASE64URL.encode('${auth.username}:${auth.password}'.codeUnits);
    return _inner.send(request);
  }
}

class RepubSpec {
  RepubSpecAuth auth;
  String hostedUrl;
  RepubSpecPushState pushState;
  RepubSpec({this.auth, this.hostedUrl, this.pushState});
  factory RepubSpec.parse(Map map) => new RepubSpec(
      auth:
          map.containsKey('auth') ? new RepubSpecAuth.parse(map['auth']) : null,
      hostedUrl: map['hosted_url']?.toString(),
      pushState: map.containsKey('push_state')
          ? new RepubSpecPushState.parse(map['push_state'])
          : null);

  factory RepubSpec.fromYaml(String str) {
    yaml.YamlMap y = yaml.loadYaml(str);
    return new RepubSpec.parse(y);
  }

  static Future<RepubSpec> load(Directory dir, {bool fallback: false}) async {
    var file = new File.fromUri(dir.uri.resolve('repubspec.yaml'));

    if (!await file.exists()) {
      if (fallback != true)
        return null;
      else
        return await RepubSpec.load(Directory.current);
    }

    return new RepubSpec.fromYaml(await file.readAsString());
  }

  static RepubSpec loadSync(Directory dir, {bool fallback: false}) {
    var file = new File.fromUri(dir.uri.resolve('repubspec.yaml'));

    if (!file.existsSync()) {
      if (fallback != true)
        return null;
      else
        return RepubSpec.loadSync(Directory.current);
    }

    return new RepubSpec.fromYaml(file.readAsStringSync());
  }
}

class RepubSpecAuth {
  String type, username, password;
  RepubSpecAuth({this.type, this.username, this.password});
  factory RepubSpecAuth.parse(Map map) => new RepubSpecAuth(
      type: map['type'], username: map['username'], password: map['password']);
}

class RepubSpecPushState {
  String base;
  RepubSpecPushState({this.base});
  factory RepubSpecPushState.parse(Map map) =>
      new RepubSpecPushState(base: map['base']?.toString());
}
