// Copyright (c) 2013, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'package:repub/src/entrypoint.dart';
import 'package:repub/src/validator.dart';
import 'package:repub/src/validator/dependency_override.dart';
import 'package:scheduled_test/scheduled_test.dart';

import '../descriptor.dart' as d;
import '../test_pub.dart';
import 'utils.dart';

Validator dependencyOverride(Entrypoint entrypoint) =>
    new DependencyOverrideValidator(entrypoint);

main() {
  integration(
      'should consider a package valid if it has dev dependency '
      'overrides', () {
    d.dir(appPath, [
      d.pubspec({
        "name": "myapp",
        "dev_dependencies": {"foo": "1.0.0"},
        "dependency_overrides": {"foo": "<3.0.0"}
      })
    ]).create();

    expectNoValidationError(dependencyOverride);
  });

  group('should consider a package invalid if', () {
    integration('it has only non-dev dependency overrides', () {
      d.dir(appPath, [
        d.pubspec({
          "name": "myapp",
          "dependency_overrides": {"foo": "<3.0.0"}
        })
      ]).create();

      expectValidationError(dependencyOverride);
    });

    integration('it has any non-dev dependency overrides', () {
      d.dir(appPath, [
        d.pubspec({
          "name": "myapp",
          "dev_dependencies": {"foo": "1.0.0"},
          "dependency_overrides": {
            "foo": "<3.0.0",
            "bar": ">3.0.0",
          }
        })
      ]).create();

      expectValidationError(dependencyOverride);
    });
  });
}
